==> haskell-mime-types-0.1.0.7-8-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-mime-types.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: mime-types
version: 0.1.0.7
id: mime-types-0.1.0.7-FBTbThCZY4IAxCrf9Kjzw3
key: mime-types-0.1.0.7-FBTbThCZY4IAxCrf9Kjzw3
license: MIT
maintainer: michael@snoyman.com
homepage: https://github.com/yesodweb/wai
synopsis: Basic mime-type handling types and functions
description:
    API docs and the README are available at <http://www.stackage.org/package/mime-types>.
category: Web
author: Michael Snoyman
exposed: True
indefinite: False
exposed-modules:
    Network.Mime
abi: 876b8a8b9446742c5332d5115f2c1813
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/mime-types-0.1.0.7
library-dirs: /usr/lib/ghc-8.2.2/site-local/mime-types-0.1.0.7
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.2/mime-types-0.1.0.7
hs-libraries: HSmime-types-0.1.0.7-FBTbThCZY4IAxCrf9Kjzw3
depends:
    base-4.10.1.0 containers-0.5.10.2
    text-1.2.3.0-6107d52Rn3mLJ1xgqHMkbj bytestring-0.10.8.2
abi-depends: base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
             containers-0.5.10.2=0f9db0d1b935cacba444aac19f4cb54d
             text-1.2.3.0-6107d52Rn3mLJ1xgqHMkbj=b7726d921cac66adc5c8f9f66f5b25f0
             bytestring-0.10.8.2=4b2726b654ceeff6535e698a2a1e724e
haddock-interfaces: /usr/share/doc/haskell-mime-types/html/mime-types.haddock
haddock-html: /usr/share/doc/haskell-mime-types/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-mime-types-0.1.0.7-9-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-mime-types.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: mime-types
version: 0.1.0.7
id: mime-types-0.1.0.7-3ciIWixGGcLDbQRT9gvOgP
key: mime-types-0.1.0.7-3ciIWixGGcLDbQRT9gvOgP
license: MIT
maintainer: michael@snoyman.com
homepage: https://github.com/yesodweb/wai
synopsis: Basic mime-type handling types and functions
description:
    API docs and the README are available at <http://www.stackage.org/package/mime-types>.
category: Web
author: Michael Snoyman
exposed: True
indefinite: False
exposed-modules:
    Network.Mime
abi: a2e807280038d0a00de8a1cdd4b5e956
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/mime-types-0.1.0.7
library-dirs: /usr/lib/ghc-8.2.2/site-local/mime-types-0.1.0.7
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.2/mime-types-0.1.0.7
hs-libraries: HSmime-types-0.1.0.7-3ciIWixGGcLDbQRT9gvOgP
depends:
    base-4.10.1.0 containers-0.5.10.2
    text-1.2.3.0-912fnkqHcZz4dFvcXKwtDz bytestring-0.10.8.2
abi-depends: base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
             containers-0.5.10.2=0f9db0d1b935cacba444aac19f4cb54d
             text-1.2.3.0-912fnkqHcZz4dFvcXKwtDz=29872508833c96394f0471371217bab0
             bytestring-0.10.8.2=4b2726b654ceeff6535e698a2a1e724e
haddock-interfaces: /usr/share/doc/haskell-mime-types/html/mime-types.haddock
haddock-html: /usr/share/doc/haskell-mime-types/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
